import React, {useState, useEffect, useContext} from 'react';
import List from '@mui/material/List';
import { AdaptiveContext } from '../App'

import {Link} from 'react-router-dom'

import { ChatAvatar } from "../components"
import { connect }  from 'react-redux'


const Chat = ({ chat, currChat, myId, lv }) => {

  const [newMsgCount, setNewMsgCount] = useState( chat.messages &&
                     (chat.messages.filter(msg => ( !currChat && (msg.owner._id !== myId) && (msg.createdAt > chat.lastVizited)) )).length )
  
  const [msgText, setMsgText] = useState( chat.messages && (
                                            chat.messages[chat.messages.length - 1]?.text || 
                                                (chat.messages[chat.messages.length - 1]?.media && 'медиа') ) || '...')


  useEffect(() => {

    setNewMsgCount( chat.messages &&
            (chat.messages.filter(msg => ( !currChat && (msg.owner._id !== myId) && (msg.createdAt > chat.lastVizited)) )).length )

    setMsgText( chat.messages && (
                    chat.messages[chat.messages.length - 1]?.text || 
                        (chat.messages[chat.messages.length - 1]?.media && 'медиа') ) || '...' )
  }, [chat, currChat, lv])

  const contextObj = useContext(AdaptiveContext)
  return (
    <Link 
      style={{ textDecoration: 'none' }}
      to={`/main/${chat._id}`}
      onClick={() => {
        contextObj.setAside(false)
      }}
      >
     
      <div
        className={`chatItem ${currChat ? "selectedChat" : "notSelectedChat"} `}
        >
        <div className={"chatAvatar"}>
          <ChatAvatar chat={chat} />
        </div>   

        <div className={"chatBody"}>

          <div className={"chatTitle"}>

            <div className={"chatName"}>
              {chat.title} 
            </div> 

            <div className={"chatStatus"}>
      
            </div> 
          </div> 

          <div className={"chatSubTitle"}>

            <div className={"chatText"}>
              {msgText}
            </div> 

            <div className={"chatMsgCount"}>
              { !!newMsgCount && 
                <div className={"countWrapper"}>
                  {newMsgCount || ''}
                </div> 
              }
             
            </div> 
          </div> 

        </div>
              
      </div>
    </Link>
  )
}
const CChat = connect( state => ({ myId: state.promise.myProfile?.payload?._id || null }))(Chat)



const ChatList = ({ chats=[], currChatId }) => {

  return (
      <List        
        sx={{ maxWidth: '100%', bgcolor: 'background.paper' }}
        >
          <div>
             
              {chats.map(chat =>          
                    <CChat key={chat._id} chat={chat} currChat={currChatId === chat._id} lv={chat.lastVizited} /> 
              )}  
          </div>  
      </List>      
  )
}
export const CChatList = connect( state => ({ chats: Object.values(state.chats).filter(el => !!el._id) }))(ChatList)

