import React, {useState, useEffect, useContext} from 'react'
import { useTheme } from '@mui/material/styles';
import useMediaQuery from '@mui/material/useMediaQuery';
import IconButton from '@mui/material/IconButton';
import ArrowBackIcon from '@mui/icons-material/ArrowBack';
import MoreVertIcon from '@mui/icons-material/MoreVert';
import Menu from '@mui/material/Menu';
import MenuItem from '@mui/material/MenuItem';

import {Link} from 'react-router-dom'

import { AdaptiveContext } from '../App'

import { ChatAvatar, CChatModal } from "../components"

import { printEnding } from "../helpers"
import { removeUserChat } from "../actions"
import { connect } from 'react-redux'


const chatMngBody = {
   width: "100%",
   display: "flex",
   justifyContent: "flex-start",
   aligneItems: "center"
}
   const blockMobile = {
      flexShrink: 0,
      flexGrow: 0,
      flexBasis: "50px",
      display: "flex",
      justifyContent: "flex-start",
      aligneItems: "center",
   }
   const blockLeft = {
      flexGrow: 1,
      width: "calc(100% - 100px)",
      display: "flex",
      justifyContent: "flex-start",
      aligneItems: "center",
      cursor: "pointer"
   }
      const blockAv = {
         flexShrink: 0,
         flexGrow: 0,
         flexBasis: "40px",
         margin: "auto 0"
      }
      const blockInfo = {
         display: "flex",
         flexDirection: "column",
         justifyContent: "space-between",
         overflow: "hidden",
         whiteSpace: "nowrap",
         textOverflow: "ellipsis",
         marginLeft: "15px",
         userSelect: "none",
      }
         const blockName = {
            fontSize: "16px",
            fontWeight: "500",
         }
         const blockMemb = {
            fontSize: "14px",
            fontWeight: "300",
         }
   const blockRight = {
      flexShrink: 0,
      flexGrow: 0,
      flexBasis: "50px",
      display: "flex",
      justifyContent: "flex-end",
      aligneItems: "center"
   }



const chatMinInfo = ({ chat, OPEN }) => {
   if (chat) {
      return (
         <div style={blockLeft} onClick={OPEN}>
            <div style={blockAv}>
               <ChatAvatar chat={chat} />
            </div>
            <div style={blockInfo}>
               <div style={blockName}>
                  {chat.title}
               </div>
               <div style={blockMemb}>
                  {chat.members && `${chat.members.length} участник${printEnding(String(chat.members.length))}`} 
               </div>
            </div>
         </div>
      )
   } else {
      return (
         <></>
      )
   }
}


const ChatMenu = ({ chatId, onLeave }) => {
   const [anchorEl, setAnchorEl] = useState(null)
   const open = !!anchorEl

   const handleClick = (event) => {
     setAnchorEl(event.currentTarget)
   }

   const handleClose = () => {
     setAnchorEl(null)
   }

   return (
      <>
         <IconButton 
               style={{ color: '#fff' }} 
               onClick={handleClick}>
            <MoreVertIcon />
         </IconButton>
   
         <Menu
            anchorEl={anchorEl}
            open={open}
            onClose={handleClose}
         >

            <MenuItem onClick={handleClose}>
               Что то сделать
            </MenuItem>

            <MenuItem onClick={() => onLeave(chatId)}>
               Покинуть чат
            </MenuItem>
                                    
         </Menu>
      </>
   ) 
}
const CChatMenu = connect(null, {onLeave: removeUserChat})(ChatMenu)



const ChatMngHeader = ({ chats, chatId }) => {

   const chat = chats[chatId]

   const theme = useTheme()
   const matches = useMediaQuery(theme.breakpoints.up('sm'))

   const contextObj = useContext(AdaptiveContext)
   return (
      <div style={chatMngBody}>

         { matches ||
            <div style={ blockMobile } >
               <Link
                  style={{ textDecoration: 'none' }}
                  to={`/main`}
                  onClick={() => {
                     contextObj.setAside(true)
                  }}
               >
                  <IconButton 
                     style={{ color: '#fff' }} 
                     >
                     <ArrowBackIcon />
                  </IconButton>
               </Link>
            </div>
         }

         <CChatModal key={chatId} create={false} chat={chat} render={chatMinInfo} />         

         <div style={blockRight}>
            <CChatMenu chatId={chatId} />
         </div>
      </div>
   )
}
export const CChatMngHeader = connect(state => ( { chats: state.chats || []} ))(ChatMngHeader)


