import React, {useState} from 'react'
import IconButton from '@mui/material/IconButton';
import MenuIcon from '@mui/icons-material/Menu';

import Drawer from '@mui/material/Drawer';
import Box from '@mui/material/Box';
import List from '@mui/material/List';
import Divider from '@mui/material/Divider';
import ListItem from '@mui/material/ListItem';
import ListItemText from '@mui/material/ListItemText';
import Typography from '@mui/material/Typography';

import {actionFullLogout} from "../actions"
import {connect}  from 'react-redux';

import {CProfileModal, CMyAvatar} from '.'


const LogoutBtn = ({onLogout}) => (
   <>
      <ListItem button onClick={() => onLogout()} >
         <ListItemText primary={'Выйти'} />
      </ListItem>
   </>
)
const CLogoutBtn = connect(null, {onLogout: actionFullLogout})(LogoutBtn)


const AboutMe = ({ myProfile }) => {
   const {login, nick} = myProfile
return (
   <>
      <Box sx={{ display: 'flex', flexDirection: 'column', 
                     justifyContent: 'start', alignItems: 'center', 
                     background: '#dddddd44' }}>
         
         <Box  sx={{ m: 2, mb: 1 }}
               className="avatarInModal">
            <CMyAvatar bigSize={true} />
         </Box> 

         <Box sx={{ mx: 2, display: 'flex', justifyContent: 'center', 
                     alignSelf: 'start',  maxWidth: '90%' }}>
            <Typography component="h6" variant="h6" 
                        sx={{ overflow: 'hidden', whiteSpace: 'nowrap', textOverflow: 'ellipsis' }}>
               {nick}
            </Typography>
         </Box> 

         <Box sx={{ mx: 2, mb: 2, display: 'flex', justifyContent: 'center', 
                     alignSelf: 'start', maxWidth: '90%' }}>
            <Typography variant="body" 
                        sx={{ overflow: 'hidden', whiteSpace: 'nowrap', textOverflow: 'ellipsis' }}>
               {login}
            </Typography>
         </Box> 

      </Box>
   </>
) 
}
const CAboutMe = connect( state => ({ myProfile: state.promise.myProfile?.payload || {} }))(AboutMe)


export const MenuDrawer = ({ }) => {
   const [state, setState] = useState(false);
   const open = !!state

 
   const toggleDrawer = (open) => (event) => {
     if ( event.type === 'keydown' && 
          ( event.key === 'Tab' || 
            event.key === 'Shift')) {
       return
     } 
     setState(open)
   } 

   return (
     <div>
         <IconButton edge="start" color="inherit" sx={{ mr: 1 }}
            onClick={toggleDrawer(true)}
            >
            
            <MenuIcon />
         </IconButton>
         

         <Drawer
            open={state}
            onClose={toggleDrawer(false)}
            >
            <Box
               sx={{ width: 250, overflow: 'hidden',  }}
               role="presentation"
               >

               <CAboutMe />    


               <List>
                  <CProfileModal />

                  <ListItem button >
                     <ListItemText primary={'Контакты'} />
                  </ListItem>

                  <Divider />

                  <CLogoutBtn />

               </List>
            </Box>

         </Drawer>
     </div>
   );
 }


