import React, {useEffect, useState} from 'react';
import List from '@mui/material/List';
import Box from '@mui/material/Box';
import IconButton from '@mui/material/IconButton';
import AddIcon from '@mui/icons-material/Add';

import { UserCard, SearchBlock } from '.'

import { connect }  from 'react-redux'
import { actionFindUsers } from '../actions'


const AddBtn = ({onEvent}) => (
   <IconButton edge="end" onClick={onEvent}>
      <AddIcon />
   </IconButton>
)

const UserSearch = ({ findedUsers, onSearch, alreadySearched=[], onAdd, open }) => {

   const [finded, setFinded] = useState([])
   const [input, setInput] = useState(null)

   useEffect( () => {
      let timeout
      if (input !== null) {
         timeout = setTimeout(() => {
            onSearch(input)
         }, 500)
      }
      return () => {
         clearTimeout(timeout)
      }
   },[input])

   useEffect(() => {
      setFinded(findedUsers)
   },[findedUsers])
   
   useEffect(() => {
      setInput(null)
      setFinded([])
   },[open])

   return (
 
      <Box sx={{ flexBasis: "45%" }} >
         <Box sx={{ height: "40px" }}>
            <SearchBlock setInput={setInput} text={'Найти пользователя'} />
         </Box>

         <Box sx={{ height: "calc(100% - 40px)", overflowY: "auto" }}>
            <List
               sx={{ maxWidth: '100%', bgcolor: 'background.paper' }}
               >
               { finded.map((user) =>    
                                    <UserCard key={user._id} user={user} 
                                       render={AddBtn}  onAction={() => onAdd(user)} 
                                          disabled={!!alreadySearched.find((searchedUser) => searchedUser._id === user._id)} />)}
            </List>
         </Box>
      </Box>

   )
 }
 export const CUserSearch = connect( state => ( { findedUsers: state.promise.findUsers?.payload || [] }), 
                                        { onSearch: actionFindUsers } )(UserSearch)
 
